@@ -2,8 +2,7 @@
 this module contains ready-to-test examples from the EDI@Energy Documents
 https://www.edi-energy.de/index.php?id=38&tx_bdew_bdew%5Buid%5D=1486&tx_bdew_bdew%5Baction%5D=download&tx_bdew_bdew%5Bcontroller%5D=Dokument&cHash=6d81fa28a8c94fb46ebab5e0088d641e
 """
-from ebdtable2graph import EbdTable
-from ebdtable2graph.models.ebd_table import EbdCheckResult, EbdTableMetaData, EbdTableRow, EbdTableSubRow
+from ebdtable2graph.models import EbdCheckResult, EbdTable, EbdTableMetaData, EbdTableRow, EbdTableSubRow
 
 # todo @ konstantin
 # the "manual" EBDs that cause problems with the existing code are e.g.:
